@@ -39,14 +39,21 @@ class TagFile:
                    suffix)
             req = urllib2.Request(url)
             filename = None
-            
+
             if req.get_type() != "file":
                 filename = "%s_%s_%s_%s" % (req.get_host(), dist, component, tagfile_type)
             else:
                 # Make a more or less dummy filename for local URLs.
                 filename = os.path.split(req.get_selector())[0].replace(os.sep, "_")
-            
+
             fullname = os.path.join(dirname, filename)
+            if req.get_type() == "file":
+                # Always refresh.  TODO: we should use If-Modified-Since for
+                # remote HTTP tag files.
+                try:
+                    os.unlink(fullname)
+                except OSError:
+                    pass
             if not os.path.exists(fullname):
                 print "Downloading", req.get_full_url(), "file ..."
 
@@ -72,8 +79,8 @@ class TagFile:
                             raise RuntimeError("Unknown suffix '%s'" % suffix)
 
                         f = open(fullname, "w")
-                        for line in compressed_f:
-                            print >>f, line,
+                        print >>f, compressed_f.read(),
+                        f.flush()
                         f.close()
 
                         compressed_f.close()
@@ -89,15 +96,15 @@ class TagFile:
         tag_files = []
         for mirror in mirrors:
             tag_file = None
-            for suffix in (".bz2", ".gz"):
+            for suffix in (".bz2", ".gz", ""):
                 try:
                     tag_file = open_tag_file(mirror, suffix)
+                    tag_files.append(tag_file)
                     break
                 except (IOError, OSError):
                     pass
-            if tag_file is None:
-                tag_file = open_tag_file(mirror, "")
-            tag_files.append(tag_file)
+        if len(tag_files) == 0:
+            raise IOError, "no %s files found" % tagfile_type
         return tag_files
 
     def feed(self, g, dists, components, arch, cleanup=False):
